## What is it?
**uwmxhelper** is a Python package that supports data aggregation and visualization in the field of urban water management. It provides all functions required in the ETH Zurich lecture [Urban Drainage Planning and Modelling](https://sww.ifu.ethz.ch/education/lectures/urban-drainage.html).

## Main Features
**uwmxhelper** provides wrapper functions for:
- ...
- ...

## Where to get it
The source code is currently hosted on ... (**TBD**).
The binary installer for the latest released version is available at the Python Package Index (PyPI):
```
pip install uwmxhelper
```

## Dependencies
- [Pandas](https://pandas.pydata.org/)
- [Numpy](https://numpy.org/)
- ...

## Documentation
The official documentation is hosted on ...

## Background
Work on **uwmxhelper** started at the [Chairs of Urban Water Management](https://sww.ifu.ethz.ch/) (ETH Zurich) in 2021 and has been under active development since then.

## Getting Help
<sww@ifu.baug.ethz.ch>